import 'package:flutter/material.dart';
import 'package:flutter/painting.dart';

/// On Relative luminance: https://www.w3.org/TR/WCAG20/#relativeluminancedef
class RelativeLuminance {
  /// Calculates relative luminance of the color after converting it to the
  /// sRGB color space.
  ///
  /// For 255 alpha, we already have our color in sRGB space.
  /// For colors with transparency, we need to get them to sRGB using alpha blending.
  ///
  /// We can take a background(with possible transparency),
  /// a solidBackdrop(absolutely needs to be a solid color), and convert the
  /// whole setup to usable sRGB.
  /// Both of these values default to solid white if not supplied.
  ///
  /// Once all the alpha blends take place, we effectively have two color zones
  /// between which we will calculate the contrast ratios.
  ///
  /// This function tries to estimate the effective relative luminance of one
  /// color zone, after applying all the alpha blends from bottom to top.
  static double calculateFromColor(
    /// first color, the foreground. Ignore optional parameters if solid
    Color color, {

    /// if the foreground is not solid, provide this parameter
    Color background = const Color.fromRGBO(255, 255, 255, 1),

    /// if the background is not solid, provide this parameter
    Color solidBackdrop = const Color.fromRGBO(255, 255, 255, 1),
  }) {
    /// asserts that the solid backdrop does not have a transparency
    assert(solidBackdrop.alpha == 255);
    final _blendedColor = color.alpha == 255
        ? color
        : Color.alphaBlend(color, Color.alphaBlend(background, solidBackdrop));
    return _blendedColor.computeLuminance();
  }
}
